// ignore_for_file: non_constant_identifier_names
part of 'tmap_view.widget.dart';

class _IOSMapDelegate extends NSObject with QMapViewDelegate {
  OnMarkerClicked _onMarkerClicked;
  OnMarkerDrag _onMarkerDragStart;
  OnMarkerDrag _onMarkerDragging;
  OnMarkerDrag _onMarkerDragEnd;
  OnMapClicked _onMapClick;
  OnMapMove _onMapMoveStart;
  OnMapMove _onMapMoveEnd;
  _OnRequireAlwaysAuth _onRequireAlwaysAuth;
  OnMarkerClicked _onInfoWindowClicked;
  OnMultiPointClicked _onMultiPointClicked;

  QMapView _iosController;

  @override
  Future<void> mapView_didSelectAnnotationView(
    QMapView mapView,
    QAnnotationView view,
  ) async {
    await super.mapView_didSelectAnnotationView(mapView, view);
    if (_onMarkerClicked != null) {
      await _onMarkerClicked(
        Marker.ios(
          // 这里由于传入的类型是MAAnnotation, 而fluttify对于抽象类的实体子类的处理方式是找到sdk
          // 内的第一个实体子类进行实例化, 这里如果放任不管取第一个实体子类的话是MAGroundOverlay
          // 跟当前需要的MAPointAnnotation类是冲突的.
          //
          // 解决办法很简单, 把refId取出来放到目标实体类里就行了
          QPointAnnotation()
            ..refId = (await view.get_annotation(viewChannel: false)).refId,
          _iosController,
        ),
      );
    }
  }

  @override
  Future<void> mapView_annotationView_didChangeDragState_fromOldState(
    QMapView mapView,
    QAnnotationView view,
    QAnnotationViewDragState newState,
    QAnnotationViewDragState oldState,
  ) async {
    await super.mapView_annotationView_didChangeDragState_fromOldState(
      mapView,
      view,
      newState,
      oldState,
    );
    if (_onMarkerDragStart != null &&
        newState == QAnnotationViewDragState.QAnnotationViewDragStateStarting) {
      await _onMarkerDragStart(
        Marker.ios(
          await view.get_annotation(viewChannel: false),
          _iosController,
        ),
      );
    }

    if (_onMarkerDragging != null &&
        newState == QAnnotationViewDragState.QAnnotationViewDragStateDragging) {
      await _onMarkerDragging(
        Marker.ios(
          await view.get_annotation(viewChannel: false),
          _iosController,
        ),
      );
    }

    if (_onMarkerDragEnd != null &&
        newState == QAnnotationViewDragState.QAnnotationViewDragStateEnding) {
      await _onMarkerDragEnd(
        Marker.ios(
          await view.get_annotation(viewChannel: false),
          _iosController,
        ),
      );
    }
  }
}

class _AndroidMapDelegate extends java_lang_Object
    with
        com_tencent_tencentmap_mapsdk_maps_TencentMap_OnMarkerClickListener,
        com_tencent_tencentmap_mapsdk_maps_TencentMap_OnMarkerDragListener,
        com_tencent_tencentmap_mapsdk_maps_TencentMap_OnMapClickListener,
        com_tencent_tencentmap_mapsdk_maps_TencentMap_OnCameraChangeListener,
        com_tencent_tencentmap_mapsdk_maps_TencentMap_OnMyLocationChangeListener,
        com_tencent_tencentmap_mapsdk_maps_TencentMap_OnInfoWindowClickListener {
  OnMarkerClicked _onMarkerClicked;

  @override
  Future<bool> onMarkerClick(
    com_tencent_tencentmap_mapsdk_maps_model_Marker var1,
  ) async {
    await super.onMarkerClick(var1);
    if (_onMarkerClicked != null) {
      if (!await _onMarkerClicked(Marker.android(var1))) {
        await var1.showInfoWindow();
      }
    }
    return true;
  }
}
