import 'dart:async';
import 'dart:io';
import 'dart:typed_data';

import 'package:core_location_fluttify/core_location_fluttify.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:foundation_fluttify/foundation_fluttify.dart';
import 'package:tmap_map_fluttify/src/android/android.export.g.dart';
import 'package:tmap_map_fluttify/src/ios/ios.export.g.dart';

import 'enums.dart';
import 'extensions.dart';
import 'models.dart';

part 'delegates.dart';
part 'tmap_controller.dart';

typedef Future<void> _OnMapCreated(TmapController controller);

/// 腾讯地图 Widget
class TmapView extends StatefulWidget {
  const TmapView({
    Key key,
    this.onMapCreated,
  }) : super(key: key);

  /// 地图创建完成回调
  final _OnMapCreated onMapCreated;

  @override
  _TmapViewState createState() => _TmapViewState();
}

class _TmapViewState extends State<TmapView> {
  TmapController _controller;

  @override
  Widget build(BuildContext context) {
    if (Platform.isAndroid) {
      return com_tencent_tencentmap_mapsdk_maps_TextureMapView_Android(
        onViewCreated: (controller) async {
          _controller = TmapController.android(controller, this);

          await controller.onStart();

          if (widget.onMapCreated != null) {
            // 主动延迟300毫秒, 等待地图加载完成, 防止在onMapCreated里调用方法时空指针
            Future.delayed(Duration(milliseconds: 300), () => 0)
                .then((value) => widget.onMapCreated(_controller));
          }
        },
      );
    } else if (Platform.isIOS) {
      return QMapView_iOS(
        onViewCreated: (controller) async {
          _controller = TmapController.ios(controller, this);
          if (widget.onMapCreated != null) {
            await widget.onMapCreated(_controller);
          }
        },
      );
    } else {
      return Center(child: Text('未实现的平台'));
    }
  }
}
